# Copyright (c) 2000-2005, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

# To build with dom4j issue rpmbuild --with dom4j xom.spec

%define with_dom4j %{?_with_dom4j:1}%{!?_with_dom4j:0}
%define without_dom4j %{!?_with_dom4j:1}%{?_with_dom4j:0}

Summary:        XML Object Model
Name:           xom
Version:        1.2.10
Release:        %mkrel 21
Group:          Development/Java
Epoch:          1
License:        LGPLv2
URL:            http://www.xom.nu
Source0:        http://www.cafeconleche.org/XOM/%{name}-%{version}-src.tar.gz

# Don't download jaxen, set javac target/source to 1.5
Patch0:         %{name}-build.patch

BuildRequires:  ant >= 0:1.6
BuildRequires:  javapackages-local
BuildRequires:  javapackages-tools
BuildRequires:  jarjar
BuildRequires:  jaxen
BuildRequires:  junit
BuildRequires:  xalan-j2
BuildRequires:  xerces-j2
%if %{with_dom4j}
BuildRequires:  dom4j
%endif
BuildRequires:  xml-commons-apis
BuildRequires:  tagsoup
# Use JAXP implementation in JDK
BuildRequires:  java-devel
BuildRequires:  xml-commons-resolver
BuildRequires:  servlet

Requires:  jaxen
Requires:  xalan-j2
Requires:  xerces-j2
Requires:  xml-commons-apis

BuildArch: noarch


%description
XOM is a new XML object model. It is an open source (LGPL),
tree-based API for processing XML with Java that strives
for correctness, simplicity, and performance, in that order.
XOM is designed to be easy to learn and easy to use. It
works very straight-forwardly, and has a very shallow
learning curve. Assuming you're already familiar with XML,
you should be able to get up and running with XOM very quickly.

%package javadoc
Summary:        API documentation for %{name}

%description javadoc
This package provides %{summary}.

%package demo
Summary:        Samples for %{name}
Requires:       %{name} = %{epoch}:%{version}-%{release}

%description demo
This package provides %{summary}.

%prep
%setup -q -n XOM

%patch0 -p1

# fix non ASCII chars
for s in src/nu/xom/tests/BuilderTest.java\
 src/nu/xom/tests/SerializerTest.java;do
  native2ascii -encoding UTF8 ${s} ${s}
done

# Fix encoding
sed -i 's/\r//g' LICENSE.txt
sed -i "s,59 Temple Place,51 Franklin Street,;s,Suite 330,Fifth Floor,;s,02111-1307,02110-1301,"  $(find -name "*.java") \
 LICENSE.txt lgpl.txt

%build
mkdir -p lib
pushd lib
ln -sf $(build-classpath junit) junit.jar
ln -sf $(build-classpath xerces-j2) dtd-xercesImpl.jar
ln -sf $(build-classpath xalan-j2) xalan.jar
ln -sf $(build-classpath xml-commons-apis) xmlParserAPIs.jar
ln -sf $(build-classpath jaxen) jaxen.jar

# jarjar has more than one jars
while IFS=':' read -ra JARJAR_JARS; do 
    for j in "${JARJAR_JARS[@]}";do 
        ln -sf $j $(basename $j .jar)-1.0.jar
    done
done <<<$(build-classpath jarjar)
popd
mkdir -p lib2
pushd lib2
ln -sf $(build-classpath tagsoup) tagsoup-1.2.jar
ln -sf $(build-classpath xml-commons-resolver) resolver.jar

%if %{with_dom4j}
ln -sf $(build-classpath dom4j) dom4j.jar
%endif

ln -sf $(build-classpath servlet) servlet.jar
popd

ant -v compile15 jar samples betterdoc maven2

pushd build/apidocs
for f in `find -name \*.css -o -name \*.html`; do
  sed -i 's/\r//g' $f
done
popd

mv build/maven2/project.xml build/maven2/pom.xml
%pom_add_dep jaxen:jaxen build/maven2/pom.xml
%mvn_artifact build/maven2/pom.xml build/%{name}-%{version}.jar
%mvn_alias xom:xom com.io7m.xom:xom

%install
%mvn_install
# For compatibility
# jars
ln -s xom/%{name}.jar %{buildroot}%{_javadir}/%{name}.jar
#install -d -m 755 %{buildroot}%{_javadir}
#install -m 644 build/%{name}-%{version}.jar \
#  %{buildroot}%{_javadir}/%{name}.jar

# javadoc
install -d -m 755 %{buildroot}%{_javadocdir}/%{name}
cp -pr build/apidocs/* %{buildroot}%{_javadocdir}/%{name}

# demo
install -d -m 755 %{buildroot}%{_datadir}/%{name}
install -m 644 build/xom-samples.jar %{buildroot}%{_datadir}/%{name}

# POM
install -d -m 755 %{buildroot}%{_mavenpomdir}
ln -s xom/xom.pom %{buildroot}%{_mavenpomdir}/JPP-%{name}.pom
#install -m 644 build/maven2/pom.xml %{buildroot}%{_mavenpomdir}/JPP-%{name}.pom
#%add_maven_1depmap JPP-%{name}.pom %{name}.jar

%files -f .mfiles
%doc README.txt
%doc LICENSE.txt
%doc Todo.txt
%doc lgpl.txt
%{_javadir}/%{name}.jar
%{_mavenpomdir}/JPP-%{name}.pom

%files javadoc
%{_javadocdir}/%{name}
%doc LICENSE.txt
%doc lgpl.txt

%files demo
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/xom-samples.jar




%changelog
* Fri Mar 11 2016 daviddavid <daviddavid> 1:1.2.10-21.mga6
+ Revision: 989006
- fix requires adding missing epoch on demo subpackage

* Fri Mar 11 2016 neoclust <neoclust> 1:1.2.10-20.mga6
+ Revision: 988978
- Sync with fedora
- Second rebuild of the java stack

* Wed Feb 24 2016 neoclust <neoclust> 1:1.2.10-18.mga6
+ Revision: 978440
- First rebuild of the java stack
- sync package xom with fedora

* Tue Feb 09 2016 umeabot <umeabot> 1:1.0-17.mga6
+ Revision: 951528
- Mageia 6 Mass Rebuild

* Fri Jan 02 2015 daviddavid <daviddavid> 1:1.0-16.mga5
+ Revision: 808224
- Sync with fc21 (fix build failure)

* Wed Oct 15 2014 umeabot <umeabot> 1:1.0-15.mga5
+ Revision: 741792
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1:1.0-14.mga5
+ Revision: 690732
- Mageia 5 Mass Rebuild

* Tue Aug 19 2014 luigiwalser <luigiwalser> 1:1.0-13.mga5
+ Revision: 665540
- drop gcj support (from fedora)

* Fri Oct 18 2013 umeabot <umeabot> 1:1.0-12.mga4
+ Revision: 520710
- Mageia 4 Mass Rebuild

* Mon Jan 14 2013 umeabot <umeabot> 1:1.0-11.mga3
+ Revision: 387235
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 09 2013 solbu <solbu> 1:1.0-10.mga3
+ Revision: 343556
- Spec cleanup
- Fix Requires

* Mon Jan 07 2013 dmorgan <dmorgan> 1:1.0-9.mga3
+ Revision: 341060
- Revert to version 1.0

* Fri Nov 11 2011 gil <gil> 0:1.2.1-1.mga2
+ Revision: 166422
- update to 1.2.1 , added m2 pom

* Sun Jan 16 2011 dmorgan <dmorgan> 0:1.2b1-0.0.5.mga1
+ Revision: 20261
- Fix find of javac and boot strap
- imported package xom


* Sat Dec 04 2010 Oden Eriksson <oeriksson@mandriva.com> 0:1.2b1-0.0.5mdv2011.0
+ Revision: 608225
- rebuild

* Wed Mar 17 2010 Oden Eriksson <oeriksson@mandriva.com> 0:1.2b1-0.0.4mdv2010.1
+ Revision: 524458
- rebuilt for 2010.1

* Sat Mar 07 2009 Antoine Ginies <aginies@mandriva.com> 0:1.2b1-0.0.3mdv2009.1
+ Revision: 350879
- rebuild

* Fri Dec 21 2007 Olivier Blin <oblin@mandriva.com> 0:1.2b1-0.0.2mdv2009.0
+ Revision: 136618
- restore BuildRoot

* Thu Dec 20 2007 David Walluck <walluck@mandriva.org> 0:1.2b1-0.0.2mdv2008.1
+ Revision: 135399
- build with gcj for now
- 1.2b1

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

  + Anssi Hannula <anssi@mandriva.org>
    - buildrequire java-rpmbuild, i.e. build with icedtea on x86(_64)

* Sun Dec 09 2007 David Walluck <walluck@mandriva.org> 0:1.1-0.0.1mdv2008.1
+ Revision: 116657
- 1.1

* Sat Sep 15 2007 Anssi Hannula <anssi@mandriva.org> 0:1.0-4.3mdv2008.0
+ Revision: 87300
- rebuild to filter out autorequires of GCJ AOT objects
- remove unnecessary Requires(post) on java-gcj-compat

* Wed Jul 18 2007 Anssi Hannula <anssi@mandriva.org> 0:1.0-4.2mdv2008.0
+ Revision: 53223
- use xml-commons-jaxp-1.3-apis and xml-commons-resolver12 explicitely
  instead of the generic xml-commons-apis and xml-commons-resolver which
  are provided by multiple packages (see bug #31473)

* Mon Apr 23 2007 David Walluck <walluck@mandriva.org> 0:1.0-4.1mdv2008.0
+ Revision: 17156
- Import xom



* Mon Apr 23 2007 David Walluck <walluck@mandriva.org> 0:1.0-4.1mdv2008.0
- release

* Mon Feb 12 2007 Ralph Apel <r.apel at r-apel.de> - 0:1.0-4jpp
- Add option to build core on bootstrap
- Add gcj_support option

* Tue Feb 28 2006 Fernando Nasser <fnasser@redhat.com> - 0:1.0-3jpp
- Remove dependency on clover10 (non-free)

* Sun Feb 26 2006 Fernando Nasser <fnasser@redhat.com> - 0:1.0-2jpp
- First JPP 1.7 release

* Wed Aug 17 2005 Ralph Apel <r.apel at r-apel.de> - 0:1.0-1jpp
- First JPP release
